@@ -57,6 +57,13 @@ _configure_instance(Ipc_Instance *inst)
 
    _set_instance_theme(inst);
 
+   if (inst->colorscheme)
+   {
+        eina_stringshare_replace(&(config->color_scheme_name), inst->colorscheme);
+        config_compute_color_scheme(config);
+        config->temporary = EINA_TRUE;
+   }
+
    if (inst->background)
      {
         eina_stringshare_replace(&(config->background), inst->background);
@@ -221,6 +228,7 @@ main_ipc_new(Ipc_Instance *inst)
    if (inst->visual_bell) nargc += 1;
    if (inst->cmd) nargc += 2;
    if (inst->theme) nargc += 2;
+   if (inst->colorscheme) nargc += 2;
 
    nargv = calloc(nargc + 1, sizeof(char *));
    if (!nargv) return;
@@ -247,6 +255,11 @@ main_ipc_new(Ipc_Instance *inst)
         nargv[i++] = "-t";
         nargv[i++] = (char *)inst->theme;
      }
+   if (inst->colorscheme)
+     {
+        nargv[i++] = "--colorscheme";
+        nargv[i++] = (char *)inst->colorscheme;
+     }
    if (inst->role)
      {
         nargv[i++] = "-r";
@@ -384,7 +397,7 @@ main_ipc_new(Ipc_Instance *inst)
                 inst->borderless, inst->override, inst->maximized);
    if (!wn)
      {
-        CRITICAL(_("Could not create window."));
+        CRITICAL(_("Could not create window"));
         ecore_app_args_set(pargc, (const char **)pargv);
         free(nargv);
         return;
@@ -403,7 +416,7 @@ main_ipc_new(Ipc_Instance *inst)
                    inst->title);
    if (!term)
      {
-        CRITICAL(_("Could not create terminal widget."));
+        CRITICAL(_("Could not create terminal widget"));
         win_free(wn);
         ecore_app_args_set(pargc, (const char **)pargv);
         free(nargv);
@@ -440,69 +453,71 @@ static Ecore_Getopt options = {
    PACKAGE_VERSION,
    gettext_noop("(C) 2012-%d Carsten Haitzler and others"),
    "BSD 2-Clause",
-   gettext_noop("Terminal emulator written with Enlightenment Foundation Libraries."),
+   gettext_noop("Terminal emulator written with Enlightenment Foundation Libraries"),
    EINA_TRUE,
    {
+      ECORE_GETOPT_STORE_STR ('b', "background",
+                              gettext_noop("Use the named file as a background wallpaper")),
+      ECORE_GETOPT_STORE_STR ('d', "current-directory",
+                              gettext_noop("Change to directory for execution of terminal command")),
       ECORE_GETOPT_BREAK_STR ('e', "exec",
                               gettext_noop("Command to execute. Defaults to $SHELL (or passwd shell or /bin/sh)")),
-      ECORE_GETOPT_STORE_STR ('d', "current-directory",
-                              gettext_noop("Change to directory for execution of terminal command.")),
       ECORE_GETOPT_STORE_STR ('t', "theme",
-                              gettext_noop("Use the named edje theme or path to theme file.")),
-      ECORE_GETOPT_STORE_STR ('b', "background",
-                              gettext_noop("Use the named file as a background wallpaper.")),
+                              gettext_noop("Use the named edje theme or path to theme file")),
+      ECORE_GETOPT_STORE_STR ('C', "colorscheme",
+                              gettext_noop("Use the named color scheme")),
       ECORE_GETOPT_STORE_STR ('g', "geometry",
-                              gettext_noop("Terminal geometry to use (eg 80x24 or 80x24+50+20 etc.).")),
+                              gettext_noop("Terminal geometry to use (eg 80x24 or 80x24+50+20 etc.)")),
       ECORE_GETOPT_STORE_STR ('n', "name",
-                              gettext_noop("Set window name.")),
+                              gettext_noop("Set window name")),
       ECORE_GETOPT_STORE_STR ('r', "role",
-                              gettext_noop("Set window role.")),
+                              gettext_noop("Set window role")),
       ECORE_GETOPT_STORE_STR ('T', "title",
-                              gettext_noop("Set window title.")),
+                              gettext_noop("Set window title")),
       ECORE_GETOPT_STORE_STR ('i', "icon-name",
-                              gettext_noop("Set icon name.")),
+                              gettext_noop("Set icon name")),
       ECORE_GETOPT_STORE_STR ('f', "font",
-                              gettext_noop("Set font (NAME/SIZE for scalable, NAME for bitmap.")),
+                              gettext_noop("Set font (NAME/SIZE for scalable, NAME for bitmap)")),
       ECORE_GETOPT_STORE_STR ('S', "split",
                               gettext_noop("Split the terminal window."
                               " 'v' for vertical and 'h' for horizontal."
                               " Can be used multiple times. eg -S vhvv or --split hv"
-                              " More description available on the man page.")),
+                              " More description available on the man page")),
       ECORE_GETOPT_STORE_BOOL('l', "login",
-                              gettext_noop("Run the shell as a login shell.")),
+                              gettext_noop("Run the shell as a login shell")),
       ECORE_GETOPT_STORE_BOOL('m', "video-mute",
-                              gettext_noop("Set mute mode for video playback.")),
+                              gettext_noop("Set mute mode for video playback")),
       ECORE_GETOPT_STORE_BOOL('c', "cursor-blink",
-                              gettext_noop("Set cursor blink mode.")),
+                              gettext_noop("Set cursor blink mode")),
       ECORE_GETOPT_STORE_BOOL('G', "visual-bell",
-                              gettext_noop("Set visual bell mode.")),
+                              gettext_noop("Set visual bell mode")),
       ECORE_GETOPT_STORE_TRUE('F', "fullscreen",
-                              gettext_noop("Go into the fullscreen mode from the start.")),
+                              gettext_noop("Go into the fullscreen mode from the start")),
       ECORE_GETOPT_STORE_TRUE('I', "iconic",
-                              gettext_noop("Go into an iconic state from the start.")),
+                              gettext_noop("Go into an iconic state from the start")),
       ECORE_GETOPT_STORE_TRUE('B', "borderless",
-                              gettext_noop("Become a borderless managed window.")),
+                              gettext_noop("Become a borderless managed window")),
       ECORE_GETOPT_STORE_TRUE('O', "override",
-                              gettext_noop("Become an override-redirect window.")),
+                              gettext_noop("Become an override-redirect window")),
       ECORE_GETOPT_STORE_TRUE('M', "maximized",
-                              gettext_noop("Become maximized from the start.")),
+                              gettext_noop("Become maximized from the start")),
       ECORE_GETOPT_STORE_TRUE('W', "nowm",
-                              gettext_noop("Terminology is run without a window manager.")),
+                              gettext_noop("Terminology is run without a window manager")),
       ECORE_GETOPT_STORE_TRUE('H', "hold",
-                              gettext_noop("Do not exit when the command process exits.")),
+                              gettext_noop("Do not exit when the command process exits")),
       ECORE_GETOPT_STORE_TRUE('s', "single",
-                              gettext_noop("Force single executable if multi-instance is enabled.")),
+                              gettext_noop("Force single executable if multi-instance is enabled")),
       ECORE_GETOPT_STORE_TRUE('2', "256color",
-                              gettext_noop("Set TERM to 'xterm-256color' instead of 'xterm'.")),
+                              gettext_noop("Set TERM to 'xterm-256color' instead of 'xterm'")),
       ECORE_GETOPT_STORE_DOUBLE('\0', "scale",
-                              gettext_noop("Set scaling factor.")),
+                              gettext_noop("Set scaling factor")),
       ECORE_GETOPT_STORE_BOOL('\0', "active-links",
-                              gettext_noop("Highlight links.")),
+                              gettext_noop("Highlight links")),
       ECORE_GETOPT_STORE_BOOL('\0', "no-wizard",
-                              gettext_noop("Do not display wizard on start up.")),
+                              gettext_noop("Do not display wizard on start up")),
 
       ECORE_GETOPT_VERSION   ('V', "version"),
-      ECORE_GETOPT_COPYRIGHT ('C', "copyright"),
+      ECORE_GETOPT_COPYRIGHT ('\0', "copyright"),
       ECORE_GETOPT_LICENSE   ('L', "license"),
       ECORE_GETOPT_HELP      ('h', "help"),
       ECORE_GETOPT_SENTINEL
@@ -525,16 +540,16 @@ _translate_options(void)
              switch (desc->action)
                {
                 case ECORE_GETOPT_ACTION_VERSION:
-                   desc->help = _("show program version.");
+                   desc->help = _("show program version");
                    break;
                 case ECORE_GETOPT_ACTION_COPYRIGHT:
-                   desc->help = _("show copyright.");
+                   desc->help = _("show copyright");
                    break;
                 case ECORE_GETOPT_ACTION_LICENSE:
-                   desc->help = _("show license.");
+                   desc->help = _("show license");
                    break;
                 case ECORE_GETOPT_ACTION_HELP:
-                   desc->help = _("show this message.");
+                   desc->help = _("show this message");
                    break;
                 default:
                    desc->help = gettext(desc->help);
@@ -578,7 +593,7 @@ _start(Ipc_Instance *instance, Eina_Bool need_scale_wizard)
    config = NULL;
    if (!wn)
      {
-        CRITICAL(_("Could not create window."));
+        CRITICAL(_("Could not create window"));
         goto exit;
      }
 
@@ -589,7 +604,7 @@ _start(Ipc_Instance *instance, Eina_Bool need_scale_wizard)
                    instance->w, instance->h, instance->hold, instance->title);
    if (!term)
      {
-        CRITICAL(_("Could not create terminal widget."));
+        CRITICAL(_("Could not create terminal widget"));
         config = NULL;
         goto exit;
      }
@@ -632,7 +647,7 @@ _start(Ipc_Instance *instance, Eina_Bool need_scale_wizard)
              else
                {
                   CRITICAL(_("invalid argument found for option -S/--split."
-                             " See --help."));
+                             " See --help"));
                   goto end;
                }
           }
@@ -804,39 +819,39 @@ elm_main(int argc, char **argv)
         .h = 1,
    };
    Ecore_Getopt_Value values[] = {
-     ECORE_GETOPT_VALUE_BOOL(cmd_options),
-     ECORE_GETOPT_VALUE_STR(instance.cd),
-     ECORE_GETOPT_VALUE_STR(instance.theme),
-     ECORE_GETOPT_VALUE_STR(instance.background),
-     ECORE_GETOPT_VALUE_STR(geometry),
-     ECORE_GETOPT_VALUE_STR(instance.name),
-     ECORE_GETOPT_VALUE_STR(instance.role),
-     ECORE_GETOPT_VALUE_STR(instance.title),
-     ECORE_GETOPT_VALUE_STR(instance.icon_name),
-     ECORE_GETOPT_VALUE_STR(instance.font),
-     ECORE_GETOPT_VALUE_STR(instance.startup_split),
+     ECORE_GETOPT_VALUE_STR(instance.background),       /* -b, --background */
+     ECORE_GETOPT_VALUE_STR(instance.cd),               /* -d, --current-directory */
+     ECORE_GETOPT_VALUE_BOOL(cmd_options),              /* -e, --exec */
+     ECORE_GETOPT_VALUE_STR(instance.theme),            /* -t, --theme */
+     ECORE_GETOPT_VALUE_STR(instance.colorscheme),      /* -C, --colorscheme */
+     ECORE_GETOPT_VALUE_STR(geometry),                  /* -g, --geometry */
+     ECORE_GETOPT_VALUE_STR(instance.name),             /* -n, --name */
+     ECORE_GETOPT_VALUE_STR(instance.role),             /* -r, --role */
+     ECORE_GETOPT_VALUE_STR(instance.title),            /* -T, --title */
+     ECORE_GETOPT_VALUE_STR(instance.icon_name),        /* -i, --icon-name */
+     ECORE_GETOPT_VALUE_STR(instance.font),             /* -f, --font */
+     ECORE_GETOPT_VALUE_STR(instance.startup_split),    /* -S, --split */
+     ECORE_GETOPT_VALUE_BOOL(instance.login_shell),     /* -l, --login */
+     ECORE_GETOPT_VALUE_BOOL(instance.video_mute),      /* -m, --video-mute */
+     ECORE_GETOPT_VALUE_BOOL(instance.cursor_blink),    /* -c, --cursor-blink */
+     ECORE_GETOPT_VALUE_BOOL(instance.visual_bell),     /* -G, --visual-bell */
+     ECORE_GETOPT_VALUE_BOOL(instance.fullscreen),      /* -F, --fullscreen */
+     ECORE_GETOPT_VALUE_BOOL(instance.iconic),          /* -I, --iconic */
+     ECORE_GETOPT_VALUE_BOOL(instance.borderless),      /* -B, --borderless */
+     ECORE_GETOPT_VALUE_BOOL(instance.override),        /* -O, --override */
+     ECORE_GETOPT_VALUE_BOOL(instance.maximized),       /* -M, --maximized */
+     ECORE_GETOPT_VALUE_BOOL(instance.nowm),            /* -W, --nowm */
+     ECORE_GETOPT_VALUE_BOOL(instance.hold),            /* -H, --hold */
+     ECORE_GETOPT_VALUE_BOOL(single),                   /* -s, --single */
+     ECORE_GETOPT_VALUE_BOOL(instance.xterm_256color),  /* -2, --256color */
+     ECORE_GETOPT_VALUE_DOUBLE(scale),                  /* --scale */
+     ECORE_GETOPT_VALUE_BOOL(instance.active_links),    /* --active-links */
+     ECORE_GETOPT_VALUE_BOOL(no_wizard),                /* --no-wizard */
 
-     ECORE_GETOPT_VALUE_BOOL(instance.login_shell),
-     ECORE_GETOPT_VALUE_BOOL(instance.video_mute),
-     ECORE_GETOPT_VALUE_BOOL(instance.cursor_blink),
-     ECORE_GETOPT_VALUE_BOOL(instance.visual_bell),
-     ECORE_GETOPT_VALUE_BOOL(instance.fullscreen),
-     ECORE_GETOPT_VALUE_BOOL(instance.iconic),
-     ECORE_GETOPT_VALUE_BOOL(instance.borderless),
-     ECORE_GETOPT_VALUE_BOOL(instance.override),
-     ECORE_GETOPT_VALUE_BOOL(instance.maximized),
-     ECORE_GETOPT_VALUE_BOOL(instance.nowm),
-     ECORE_GETOPT_VALUE_BOOL(instance.hold),
-     ECORE_GETOPT_VALUE_BOOL(single),
-     ECORE_GETOPT_VALUE_BOOL(instance.xterm_256color),
-     ECORE_GETOPT_VALUE_DOUBLE(scale),
-     ECORE_GETOPT_VALUE_BOOL(instance.active_links),
-     ECORE_GETOPT_VALUE_BOOL(no_wizard),
-
-     ECORE_GETOPT_VALUE_BOOL(quit_option),
-     ECORE_GETOPT_VALUE_BOOL(quit_option),
-     ECORE_GETOPT_VALUE_BOOL(quit_option),
-     ECORE_GETOPT_VALUE_BOOL(quit_option),
+     ECORE_GETOPT_VALUE_BOOL(quit_option),              /* -v, --version */
+     ECORE_GETOPT_VALUE_BOOL(quit_option),              /* --copyright */
+     ECORE_GETOPT_VALUE_BOOL(quit_option),              /* -L, --license */
+     ECORE_GETOPT_VALUE_BOOL(quit_option),              /* -h, --help */
 
      ECORE_GETOPT_VALUE_NONE
    };
@@ -873,17 +888,18 @@ elm_main(int argc, char **argv)
    _log_domain = eina_log_domain_register("terminology", NULL);
    if (_log_domain < 0)
      {
-        EINA_LOG_CRIT(_("Could not create logging domain '%s'."), "terminology");
+        EINA_LOG_CRIT(_("Could not create logging domain '%s'"), "terminology");
         elm_shutdown();
         return EXIT_FAILURE;
      }
 
    config_init();
+   colors_init();
 
    _main_config = config_load();
    if (key_bindings_load(_main_config) < 0)
      {
-        CRITICAL(_("Could not initialize key bindings."));
+        CRITICAL(_("Could not initialize key bindings"));
         retval = EXIT_FAILURE;
         goto end;
      }
@@ -898,7 +914,7 @@ elm_main(int argc, char **argv)
    args = ecore_getopt_parse(&options, values, argc, argv);
    if (args < 0)
      {
-        CRITICAL(_("Could not parse command line options."));
+        CRITICAL(_("Could not parse command line options"));
         retval = EXIT_FAILURE;
         goto end;
      }
@@ -923,7 +939,7 @@ elm_main(int argc, char **argv)
         if (args == argc)
           {
              CRITICAL(_("option %s requires an argument!"), argv[args-1]);
-             CRITICAL(_("invalid options found. See --help."));
+             CRITICAL(_("invalid options found. See --help"));
              goto end;
           }
 
@@ -1023,8 +1039,7 @@ elm_main(int argc, char **argv)
           }
      }
 
-   elm_theme_overlay_add(NULL,
-                         config_theme_path_default_get(instance.config));
+   elm_theme_overlay_add(NULL, theme_path_get("default"));
    elm_theme_overlay_add(NULL, config_theme_path_get(instance.config));
 
    if ((!single) && (instance.config->multi_instance))
@@ -1063,6 +1078,7 @@ elm_main(int argc, char **argv)
 
    config_del(_main_config);
    key_bindings_shutdown();
+   colors_shutdown();
    config_shutdown();
    controls_shutdown();
    eina_log_domain_unregister(_log_domain);
