@@ -1,6 +1,7 @@
 #include "private.h"
 
 #include <Elementary.h>
+#include <Elementary_Cursor.h>
 #include <Efreet.h>
 #include <assert.h>
 #include "config.h"
@@ -59,8 +60,10 @@ _cb_op_theme_content_get(void *data, Evas_Object *obj, const char *part)
 
              o = options_theme_preview_add(obj, config,
                                            theme_path_get(t->name),
+                                           NULL,
                                            128 * elm_config_scale_get(),
-                                           64 * elm_config_scale_get());
+                                           64 * elm_config_scale_get(),
+                                           EINA_FALSE);
              return o;
           }
      }
@@ -141,6 +144,7 @@ options_theme(Evas_Object *opbox, Evas_Object *term)
    Config *config = termio_config_get(term);
    Eina_Bool to_skip = EINA_FALSE;
    double scale = elm_config_scale_get();
+   const char *config_theme_name = "";
    Theme_Ctx *ctx;
 
    ctx = calloc(1, sizeof(*ctx));
@@ -149,6 +153,15 @@ options_theme(Evas_Object *opbox, Evas_Object *term)
    ctx->config = config;
    ctx->term = term;
 
+   if (config && config->theme)
+     {
+        config_theme_name = strrchr(config->theme, '/');
+        if (config_theme_name)
+          config_theme_name++;
+        else
+          config_theme_name = config->theme;
+     }
+
    fr = o = elm_frame_add(opbox);
    evas_object_size_hint_weight_set(o, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
    evas_object_size_hint_align_set(o, EVAS_HINT_FILL, EVAS_HINT_FILL);
@@ -166,6 +179,18 @@ options_theme(Evas_Object *opbox, Evas_Object *term)
    elm_object_content_set(fr, o);
    evas_object_show(o);
 
+   if (config && config->color_scheme)
+     {
+        o = elm_label_add(opbox);
+        evas_object_size_hint_weight_set(o, EVAS_HINT_EXPAND, 0);
+        evas_object_size_hint_align_set(o, EVAS_HINT_FILL, EVAS_HINT_FILL);
+        snprintf(buf, sizeof(buf), _("Using colorscheme <hilight>%s</hilight>"),
+                 config->color_scheme->md.name);
+        elm_object_text_set(o, buf);
+        elm_box_pack_end(box, o);
+        evas_object_show(o);
+     }
+
    it_class = elm_gengrid_item_class_new();
    it_class->item_style = "thumb";
    it_class->func.text_get = _cb_op_theme_text_get;
@@ -234,9 +259,7 @@ options_theme(Evas_Object *opbox, Evas_Object *term)
                                           _cb_op_theme_sel, t);
         if (t->item)
           {
-             ctx->themes = eina_list_append(ctx->themes, t);
-             if ((config) && (config->theme) &&
-                 (!strcmp(config->theme, t->name)))
+            if (!strcmp(config_theme_name, t->name))
                {
                   if (ctx->seltimer)
                     ecore_timer_del(ctx->seltimer);
