@@ -572,8 +572,9 @@ _entry_del_cb(void *data,
               void *_info EINA_UNUSED)
 {
    Entry *en = data;
-   if (en->obj) evas_object_event_callback_del_full
-     (en->obj, EVAS_CALLBACK_DEL, _entry_del_cb, en);
+   if (en->obj)
+     evas_object_event_callback_del_full(en->obj, EVAS_CALLBACK_DEL,
+                                         _entry_del_cb, en);
    en->obj = NULL;
    /*
    if (en->termio)
@@ -619,8 +620,9 @@ _smart_del(Evas_Object *obj)
    if (sd->autozoom_timeout) ecore_timer_del(sd->autozoom_timeout);
    EINA_LIST_FREE(sd->items, en)
      {
-        if (en->obj) evas_object_event_callback_del_full
-          (en->obj, EVAS_CALLBACK_DEL, _entry_del_cb, en);
+        if (en->obj)
+          evas_object_event_callback_del_full(en->obj, EVAS_CALLBACK_DEL,
+                                              _entry_del_cb, en);
         if (en->obj) evas_object_del(en->obj);
         evas_object_del(en->bg);
         free(en);
@@ -729,7 +731,8 @@ sel_entry_add(Evas_Object *obj, Evas_Object *entry,
    en->selected_before = selected;
    en->selected_orig = selected;
    en->bg = edje_object_add(evas_object_evas_get(obj));
-   theme_apply(en->bg, config, "terminology/sel/item");
+   theme_apply(en->bg, config, "terminology/sel/item",
+               NULL, NULL, EINA_FALSE);
    evas_object_smart_member_add(en->bg, obj);
    evas_object_clip_set(en->bg, sd->clip);
    edje_object_part_swallow(en->bg, "terminology.content", en->obj);
