@@ -2635,6 +2635,38 @@ termio_internal_render(Termio *sd,
                        fgext = cells[x].att.fg256;
                        bgext = cells[x].att.bg256;
                        codepoint = cells[x].codepoint;
+
+                       if ((fg == COL_DEF) && (cells[x].att.inverse ^ inv))
+                         fg = COL_INVERSEBG;
+                       if (bg == COL_DEF)
+                         {
+                            if (cells[x].att.inverse ^ inv)
+                              bg = COL_INVERSE;
+                            else if (!bgext)
+                              bg = COL_INVIS;
+                         }
+
+                       if ((cells[x].att.bgintense) && (!bgext))
+                         bg += 12;
+
+                       if (!fgext)
+                         {
+                            if ((cells[x].att.fgintense) || (cells[x].att.bold))
+                              fg += 12;
+                            if (cells[x].att.faint)
+                              fg += 2 * 12;
+                         }
+
+                       if (cells[x].att.inverse ^ inv)
+                         {
+                            int t;
+                            t = fgext; fgext = bgext; bgext = t;
+                            t = fg; fg = bg; bg = t;
+                         }
+
+                       /* if font does not have bolditalic, bright/bold
+                        * color is still applied
+                        */
                        if (sd->config->font.bolditalic)
                          {
                             bold = cells[x].att.bold;
@@ -2646,29 +2678,6 @@ termio_internal_render(Termio *sd,
                             italic = 0;
                          }
 
-                       if ((fg == COL_DEF) && (cells[x].att.inverse ^ inv))
-                         fg = COL_INVERSEBG;
-                       if (bg == COL_DEF)
-                         {
-                            if (cells[x].att.inverse ^ inv)
-                              bg = COL_INVERSE;
-                            else if (!bgext)
-                              bg = COL_INVIS;
-                         }
-                       if ((cells[x].att.fgintense) && (!fgext))
-                         fg += 48;
-                       if ((cells[x].att.bgintense) && (!bgext))
-                         bg += 48;
-                       if ((cells[x].att.bold) && (!fgext))
-                         fg += 12;
-                       if ((cells[x].att.faint) && (!fgext))
-                         fg += 24;
-                       if (cells[x].att.inverse ^ inv)
-                         {
-                            int t;
-                            t = fgext; fgext = bgext; bgext = t;
-                            t = fg; fg = bg; bg = t;
-                         }
                        if ((tc[x].codepoint != codepoint) ||
                            (tc[x].bold != bold) ||
                            (tc[x].italic != italic) ||
