@@ -5,7 +5,9 @@
 #include "termpty.h"
 #include "termptyops.h"
 #include "termiointernals.h"
+#if defined(BINARY_TYTEST) || defined(ENABLE_TEST_UI)
 #include "tytest.h"
+#endif
 #include <assert.h>
 
 #undef CRITICAL
@@ -30,7 +32,26 @@
 // handled here at all and just passed to termio to figure it out (return
 // EINA_FALSE).
 
-#if defined(ENABLE_TESTS) || defined(ENABLE_TEST_UI)
+#if defined(BINARY_TYTEST) || defined(ENABLE_TEST_UI)
+
+static int _mx;
+static int _my;
+
+void
+test_set_mouse_pointer(int mx, int my)
+{
+   _mx = mx;
+   _my = my;
+}
+
+void
+test_pointer_canvas_xy_get(int *mx, int *my)
+{
+   if (mx)
+     *mx = _mx;
+   if (my)
+     *my = _my;
+}
 
 static int
 _tytest_arg_get(const Eina_Unicode *buf, int *value)
@@ -122,7 +143,7 @@ _handle_mouse_down(Termpty *ty,
    _tytest_arg_get(buf, &value);
    ev.flags = value;
 
-#if defined(ENABLE_TESTS) || defined(ENABLE_TEST_UI)
+#if defined(BINARY_TYTEST) || defined(ENABLE_TEST_UI)
    test_set_mouse_pointer(ev.canvas.x, ev.canvas.y);
 #endif
    termio_internal_mouse_down(sd, &ev, modifiers);
@@ -159,7 +180,7 @@ _handle_mouse_up(Termpty *ty,
    _tytest_arg_get(buf, &value);
    ev.flags = value;
 
-#if defined(ENABLE_TESTS) || defined(ENABLE_TEST_UI)
+#if defined(BINARY_TYTEST) || defined(ENABLE_TEST_UI)
    test_set_mouse_pointer(ev.canvas.x, ev.canvas.y);
 #endif
    termio_internal_mouse_up(sd, &ev, modifiers);
@@ -188,7 +209,7 @@ _handle_mouse_move(Termpty *ty,
    /* MODIFIERS */
    _tytest_modifiers_get(buf, &modifiers);
 
-#if defined(ENABLE_TESTS) || defined(ENABLE_TEST_UI)
+#if defined(BINARY_TYTEST) || defined(ENABLE_TEST_UI)
    test_set_mouse_pointer(ev.cur.canvas.x, ev.cur.canvas.y);
 #endif
    termio_internal_mouse_move(sd, &ev, modifiers);
@@ -226,12 +247,63 @@ _handle_mouse_wheel(Termpty *ty,
    /* MODIFIERS */
    _tytest_modifiers_get(buf, &modifiers);
 
-#if defined(ENABLE_TESTS) || defined(ENABLE_TEST_UI)
+#if defined(BINARY_TYTEST) || defined(ENABLE_TEST_UI)
    test_set_mouse_pointer(ev.canvas.x, ev.canvas.y);
 #endif
    termio_internal_mouse_wheel(sd, &ev, modifiers);
 }
 
+static void
+_handle_color_link(Termpty *ty, const Eina_Unicode *buf)
+{
+   uint8_t r = 0, g = 0, b = 0, a = 0;
+   int value;
+   Eina_Bool found;
+   int x1 = -1, y1 = -1, x2 = -1, y2 = -1;
+   Termio *sd = termio_get_from_obj(ty->obj);
+
+   found = termio_color_find(ty->obj, sd->mouse.cx, sd->mouse.cy,
+                             &x1, &y1, &x2, &y2,
+                             &r, &g, &b, &a);
+   if (found)
+     {
+        ERR("printf '\\033}tlc;%d;%d;%d;%d;%d;%d;%d;%d\\0'",
+           x1,y1,x2,y2, r,g,b,a);
+     }
+   else
+     {
+        ERR("printf '\\033}tlcn\\0'");
+     }
+   if (*buf == 'n')
+     {
+        assert(!found);
+        return;
+     }
+   assert(found);
+
+   /* Get numeric values */
+   buf += _tytest_arg_get(buf, &value);
+   assert(x1 == value);
+   buf += _tytest_arg_get(buf, &value);
+   assert(y1 == value);
+   buf += _tytest_arg_get(buf, &value);
+   assert(x2 == value);
+   buf += _tytest_arg_get(buf, &value);
+   assert(y2 == value);
+   /* skip ; */
+   buf++;
+
+   /* Get numeric values */
+   buf += _tytest_arg_get(buf, &value);
+   assert(r == value);
+   buf += _tytest_arg_get(buf, &value);
+   assert(g == value);
+   buf += _tytest_arg_get(buf, &value);
+   assert(b == value);
+   _tytest_arg_get(buf, &value);
+   assert(a == value);
+}
+
 /*
  * Format is:
  * - ln : no link found under cursor
@@ -240,6 +312,7 @@ _handle_mouse_wheel(Termpty *ty,
  *     e: link is an email
  *     u: link is an url
  *     p: link is a file path
+ *     c: link is a color
  */
 static void
 _handle_link(Termpty *ty, const Eina_Unicode *buf)
@@ -262,6 +335,14 @@ _handle_link(Termpty *ty, const Eina_Unicode *buf)
         cells[sd->mouse.cx].att.bg = COL_RED;
      }
 
+   /* skip type */
+   buf++;
+
+   if (type == 'c')
+     {
+        _handle_color_link(ty, buf);
+        return;
+     }
    link = termio_link_find(ty->obj, sd->mouse.cx, sd->mouse.cy,
                            &x1, &y1, &x2, &y2);
 
@@ -271,8 +352,7 @@ _handle_link(Termpty *ty, const Eina_Unicode *buf)
         assert (link == NULL);
         return;
      }
-   /* skip type */
-   buf++;
+
    /* Get numeric values */
    buf += _tytest_arg_get(buf, &value);
    assert(x1 == value);
@@ -284,6 +364,7 @@ _handle_link(Termpty *ty, const Eina_Unicode *buf)
    assert(y2 == value);
    /* skip ; */
    buf++;
+
    /* Compare strings */
    c = link;
    while (*buf)
@@ -445,7 +526,7 @@ tytest_handle_escape_codes(Termpty *ty,
 }
 #endif
 
-#if defined(ENABLE_TESTS) || defined(ENABLE_TEST_UI)
+#if defined(BINARY_TYTEST) || defined(ENABLE_TEST_UI)
 #define ARG_USED_FOR_TESTS
 #else
 #define ARG_USED_FOR_TESTS EINA_UNUSED
@@ -458,7 +539,7 @@ termpty_ext_handle(Termpty *ty ARG_USED_FOR_TESTS,
 {
    switch (buf[0]) // major opcode
      {
-#if defined(ENABLE_TESTS) || defined(ENABLE_TEST_UI)
+#if defined(BINARY_TYTEST) || defined(ENABLE_TEST_UI)
       case 't':
         tytest_handle_escape_codes(ty, buf + 1);
         return EINA_TRUE;
